<?php
namespace Stock\Entity;

use Doctrine\ORM\Mapping as ORM;


/**
 * @ORM\Entity
 * @ORM\Table(name="vehicle_accessory", uniqueConstraints={@ORM\UniqueConstraint(name="unique_accessory",
 *                                      columns={"name"})})
 */
class Accessory
{

	/**
	 * Can archive records.
	 */
	const ARCHIVE = true;
	/**
	 * Pull Synchronization Strategy for this table.
	 */
	const PULL_SYNCH_STRATEGY = 'Update';
	/**
	 * Push Synchronization Strategy for this table.
	 */
	const PUSH_SYNCH_STRATEGY = 'Update';


	/**
	 * @ORM\Id
	 * @ORM\Column(type="integer");
	 * @ORM\GeneratedValue(strategy="AUTO")
	 */
	protected $id;

	/**
	 * @ORM\Column(type="string", length=75, unique=true)
	 */
	protected $name;

	/**
	 * @ORM\Column(type="smallint", nullable=true, name="create_version", options={"unsigned"=true})
	 */
	protected $createVersion;

	/**
	 * @ORM\Column(type="smallint", nullable=true, name="update_version", options={"unsigned"=true})
	 */
	protected $updateVersion;

	/**
	 * @ORM\Column(type="boolean");
	 */
	protected $archived = false;



	/**
	 * Magic getter to expose protected properties.
	 * @param string $property
	 * @return mixed
	 */
	public function __get($property)
	{
		return $this->$property;
	}

	/**
	 * Magic setter to save protected properties.
	 * @param string $property
	 * @param mixed  $value
	 */
	public function __set($property, $value)
	{
		$this->$property = $value;
	}

	/**
	 * @ORM\PrePersist
	 */
	public function setCreateVersion()
	{
		$version = 1;
		$items = \Utility\Registry::getEntityManager()
			->getRepository('Stock\\Entity\\Accessory')
			->findAll();
		foreach ($items as $item)
		{
			if ($item->createVersion > $version)
			{
				$version = $item->createVersion;
			}
			if ($item->updateVersion > $version)
			{
				$version = $item->updateVersion;
			}
		}
		$this->createVersion = $version;
	}

	/**
	 * @ORM\PreUpdate
	 */
	public function setUpdateVersion()
	{
		$version = 1;
		$items = \Utility\Registry::getEntityManager()
			->getRepository('Stock\\Entity\\Accessory')
			->findAll();
		foreach ($items as $item)
		{
			if ($item->createVersion > $version)
			{
				$version = $item->createVersion;
			}
			if ($item->updateVersion > $version)
			{
				$version = $item->updateVersion;
			}
		}
		$this->updateVersion = $version;
	}

	/**
	 * Convert the object to an array.
	 * @param array $expand
	 * @param array $intersect
	 * @return array
	 */
	public function toArray(array $expand = array(), array $intersect = array())
	{
		!empty($intersect)
		&& $intersect = array_flip($intersect);
		$includeAll = empty($intersect);
		$data       = array();
		($includeAll || isset($intersect['id']))
		&& $data['id'] = $this->id;
		($includeAll || isset($intersect['name']))
		&& $data['name'] = $this->name;
		return $data;
	}

	/**
	 * Convert the object to an array for synchronization.
	 * @return array
	 */
	public function toSynchArray()
	{
		return array(
			'id'   => $this->id,
			'name' => $this->name
		);
	}

	/**
	 * Populate from an array.
	 * @param array $data
	 */
	public function fromArray($data = array())
	{
		isset($data['id'])
		&& $this->id = $data['id'];
		isset($data['name'])
		&& $this->name = $data['name'];
		isset($data['createVersion'])
		&& $this->createVersion = $data['createVersion'];
		isset($data['updateVersion'])
		&& $this->updateVersion = $data['updateVersion'];
	}

}
