<?php
namespace Stock\Pdf;



class TuhpiAccident extends \Utility\Service\PdfTemplate
{


	/**
	 * PDF title.
	 * @var string
	 */
	protected $_title = 'HPI Accident Only Report';
	/**
	 * @var \Stock\Entity\Stock
	 */
	protected $jobRecord;

	/**
	 * @var boolean
	 */
	protected $showCustomerDetails = false;
	/**
	 * @var boolean
	 */
	protected $showValuationDetails = false;
	/**
	 * @var boolean
	 */
	protected $showPricingDetails = false;
	/**
	 * @var boolean
	 */
	protected $showVehicleDetails = false;
	/**
	 * @var boolean
	 */
	protected $showVehicleNotes = false;
	/**
	 * @var boolean
	 */
	protected $showDamageDetails = false;
	/**
	 * @var boolean
	 */
	protected $showAccessoryDetails = false;
	/**
	 * @var boolean
	 */
	protected $showSignatureLines = false;
	/**
	 * @var boolean
	 */
	protected $showTermsAndConditions = false;
	/**
	 * @var boolean
	 */
	protected $showOffersReceived = false;
	/**
	 * @var boolean
	 */
	protected $showOfferMade = false;


	/**
	 * Utility for easy parameter retrieval.
	 * @param string $param
	 * @param unknown $default
	 * @return unknown
	 */
	protected function getStockParam($param, $default)
	{
		return !is_null($this->jobRecord->$param)
			? $this->jobRecord->$param
			: $default;
	}

	/**
	 * Utility for easy parameter retrieval.
	 * @param string $param
	 * @param unknown $default
	 * @return unknown
	 */
	protected function getStockSubParam($ref, $param, $default)
	{
		$ref = !is_null($this->jobRecord->$ref)
			? $this->jobRecord->$ref
			: null;
		return is_object($ref)
			? $ref->$param
			: $default;
	}

	/**
	 * Utility for easy parameter retrieval.
	 * @param string $param
	 * @param unknown $default
	 * @return unknown
	 */
	protected function getValuationParam($param, $default)
	{
		return !is_null($this->jobRecord->valuation)
				&& !is_null($this->jobRecord->valuation->$param)
			? $this->jobRecord->valuation->$param
			: $default;
	}


	/**
	 * Build the content.
	 */
	public function build()
	{
        ini_set('memory_limit','-1');

		#-> Set data item to work with.
		$authData = \Utility\Registry::getAuthData();

        $this->jobRecord = $this->_input['jobRecord'];

        $recordId = $this->_input['contract']->PdfTemplate['recordId'];

        if(!empty($recordId) && '' != $recordId)
        {
            $result = $this->em->createQuery(
                'SELECT tuhpi '
                . 'FROM \Stock\Entity\Tuhpi tuhpi '
                . 'JOIN tuhpi.stock stock '
                . 'WHERE tuhpi.id = :id '
                . 'ORDER BY tuhpi.created ASC '
            )
                ->setParameter( 'id' , $recordId );
        }
        else
        {
            $result = $this->em->createQuery(
                'SELECT tuhpi '
                . 'FROM \Stock\Entity\Tuhpi tuhpi '
                . 'JOIN tuhpi.stock stock '
                . 'WHERE stock.id = :stockId '
                . ' AND IDENTITY(tuhpi.company) = :companyId '
                . 'ORDER BY tuhpi.created ASC '
            )
                ->setParameter( 'stockId' , $this->jobRecord->id )
                ->setParameter( 'companyId' , $authData['company']['id'] );
        }


//        \Utility\Debug::errorLog('$result->getSQL()',$result->getSQL());
//        \Utility\Debug::errorLog('$result->getParameters()',$result->getParameters());

		$result = $result->getResult();

		foreach ($result as $data)
		{

//            \Utility\Debug::errorLog('$data->id',$data->id);

			$companyProfileOffice = $data->company->contact->office;
			$companyProfilefax = $data->company->contact->fax;
			$companyRegion = $data->company->region->name;
			$companyCity = $data->company->city->name;
			$companyPostalCode = $data->company->postalCode;
			$companyStreet = $data->company->street;


//            \Utility\Debug::errorLog('$data->ah_data',$data->ah_data);

            $ah_data = unserialize($data->ah_data);


		}

		$dateTimeFormat = \Utility\Definitions\Locale::getDateTimeFormat();
		$currencyPrefix = \Utility\Definitions\Locale::getCurrencyPrefix();
		$authData = \Utility\Registry::getAuthData();
		$msg = 'NO RECORD FOUND ON OUR DATABASE';

		//\Utility\Debug::errorLog('$authData', $authData['']);

//		$test = '* Year of Manufacturer - The year of manufacture and the year of first registration normally coincides. If not, the difference is caused by vehicles being
//				manufactured/imported late in one year but being sold and first registered as new in a later year.
//				TransUnion HPI is a registered financial services provider (22938).
//				_______________________________________________________________________________________________________________________
//				Please check this confirmation carefully to ensure that you enquired on the correct VIN/Engine number. Should you have any queries, please contact
//				Customer Services at: (0861) 507 507
//				Report Date: 2014/08/15  11:22 AM ';
//
//		$dateOfPrint = 'Date of print HPI: <span style="color:#333;">' . date('Y-m-d H:i:s') . '</span>';
//		$printedBy   = 'Printed by HPI: <span style="color:#333;">' . $authData['firstName']
//					 . ' ' . $authData['familyName'] . '</span>';
//		$referenceNo = 'Reference no.: <span style="color:#333;">' . $this->jobRecord->referenceNumber . '</span>';


//		$this->_logo = '
//				<h1 style="font-size:20px; margin:0 auto; text-align:center">TRANSUNION REPORT</h1>
//				<div style="width:100%"></div>
//
//				<div style="display:block; width:115px; height:82px; margin-left:640px; margin-top:-40px; " >
//					<img  style="" width="115px" height="82px" src="' . __DIR__ . '/../../../../../public/img/app/logos/tuhpi.jpg" style="padding:0;margin:0;width:100%;" />
//				</div>
//				';



//        $this->_logo = '
//				<img width="53" height="67" alt="image" src="' . __DIR__ . '/../../../../../public/img/app/logos/logo.png"/>
//                <div style="padding-left: 1pt;text-indent: 0pt;text-align: left;margin-top: 25px;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: bold;text-decoration: none;font-size: 20.5pt;">
//                    Trans
//                    <span style=" color: #00a6d2;margin-left:-10px;">Union</span>
//                    <span style="color: #B8C8C3;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 5pt;margin-left:-7px;" >®</span>
//                </div>
//				';

        $this->_logo = '
				<div style="text-align: left;margin-bottom: 25px;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: bold;text-decoration: none;font-size: 20.5pt;">
				    <img width="261" height="50" alt="image" src="' . __DIR__ . '/../../../../../public/img/app/logos/TULogo_blue.jpg"/>
                </div>
				';


		/* --------------------------------- USER, TransUnion --------------------------------- */


//		$type = $this->jobRecord->type;
		$intro ='
            <div style="background-image:linear-gradient(to bottom,#d6d0c4,white 20%);position: relative;">
               <table style="width:100%;margin-top:-20px;">
                    <tr>
                        <td style="width:70%;">
                            <p style="line-height: 5pt;text-align: left;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 8pt;">
                                Wanderers Office Park, 52 Corlett Drive, lllovo, 2196
                            </p>
                            <p style="margin-top:-1px;line-height: 5pt;text-align: left;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 8pt;">
                                P O Box 4522, Johannesburg, 2000
                            </p>
                        </td>
                        <td style="width:30%;">
                            <p style="text-indent: 50%;line-height: 5pt;text-align: left;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 8pt;">
                                Web:
                                <a href="http://www.transunion.co.za/" target="_blank" style="color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 8pt;">
                                    www.transunion.co.za
                                </a>
                            </p>
                            <p style="margin-top:-1px;line-height: 5pt;text-align: left;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 8pt">
                                Call Centre: 0861 504 504
                            </p>
                            <p style="margin-top:-1px;line-height: 5pt;text-align: left;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 8pt">
                                Email:
                                <a href="mailto:dealersguide@transunion.co.za" style="color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 8pt;">
                                    dealersguide@transunion.co.za
                                </a>
                            </p>
                        </td>
                    </tr>
                </table>
                <p style="line-height: 20pt;text-align: left;color: #04a6cd;font-family: Arial, sans-serif;font-style: normal;font-weight: bold;text-decoration: none;font-size: 18pt;">
                    Vehicle Accident Report
                </p>
                <table style="width:90%;text-align: left;margin-top:-20px;">
                    <tr>
                        <td style="width:20%;border: 1px solid;padding-left: 5pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            Name :
                        </td>
                        <td style="width:80%;border: 1px solid;padding-left: 10pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                             ' . $authData['firstName']. ' ' . $authData['familyName'] . '
                        </td>
                    </tr>
                    <tr>
                        <td style="width:20%;border: 1px solid;padding-left: 5pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            Tel. Number :
                        </td>
                        <td style="width:80%;border: 1px solid;padding-left: 10pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            ' . $companyProfileOffice . '
                        </td>
                    </tr>
                    <tr>
                        <td style="width:20%;border: 1px solid;padding-left: 5pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            Fax Number :
                        </td>
                        <td style="width:80%;border: 1px solid;padding-left: 10pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            ' . $companyProfilefax . '
                        </td>
                    </tr>
                    <tr>
                        <td style="width:20%;border: 1px solid;padding-left: 5pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            Address :
                        </td>
                        <td style="width:80%;border: 1px solid;padding-left: 10pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            ' . $companyStreet . ' ' . $companyRegion . ' ' . $companyCity . ' ' . $companyPostalCode . '
                        </td>
                    </tr>
                    <tr>
                        <td style="width:20%;border: 1px solid;padding-left: 5pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            Date Requested :
                        </td>
                        <td style="width:80%;border: 1px solid;padding-left: 10pt;line-height: 10pt;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 10pt;">
                            ' . date('Y-m-d H:i:s') . '
                        </td>
                    </tr>
                </table>

                <div style="width:90%;margin-top:50pt;">
                    <p style="text-indent: 0pt;line-height: 56%;text-align: left;">
                        <img width="26" height="27" alt="image" src="' . __DIR__ . '/../../../../../public/img/app/logos/Image_012.jpg"/>
                        <p style="text-align: left;margin-left: 30px;margin-top: -25px;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;line-height: 12pt;font-size: 12pt;">
                            Thank you for your enquiry. The vehicle description you have submitted has been checked against our records, the result of the search is displayed below.
                        </p>
                    </p>
                    <span style="text-indent: 0pt;text-align: left;padding-top:5px;"></span>
                    <p style="text-indent: 0pt;line-height: 56%;text-align: left;">
                        <img width="29" height="26" alt="image" src="' . __DIR__ . '/../../../../../public/img/app/logos/Image_013.jpg"/>
                        <p style="text-align: left;margin-left: 30px;margin-top: -25px;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;line-height: 12pt;font-size: 12pt;">
                                To assist you we have added details explanations in each section.
                        </p>
                    </p>
                    <span style="text-indent: 0pt;text-align: left;padding-top:5px;"></span>
                    <p style="text-indent: 0pt;line-height: 56%;text-align: left;">
                        <img width="26" height="27" alt="image" src="' . __DIR__ . '/../../../../../public/img/app/logos/Image_012.jpg"/>
                        <p style="text-align: left;margin-left: 30px;margin-top: -25px;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;line-height: 12pt;font-size: 12pt;">
                            Should you have any queries please contact TransUnion on 0861 482 482 from Monday to Friday
                            08h00 -17h00 and Saturday 08h00 -13h00.
                        </p>
                    </p>
                    <span style="text-indent: 0pt;text-align: left;padding-top:5px;"></span>
                    <p style="text-indent: 0pt;line-height: 56%;text-align: left;">
                        <img width="29" height="26" alt="image" src="' . __DIR__ . '/../../../../../public/img/app/logos/Image_013.jpg"/>
                        <p style="text-align: left;margin-left: 30px;margin-top: -25px;color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;line-height: 12pt;font-size: 12pt;">
                            By accessing and relying on this report you are deemed to have read and agreed to AIS&#39;s terms and conditions as reflected at
                            <a href="http://www.motoronline.co.za/portal/page?_pageid=0,4049541,0_8493546&_dad=portal30&_schema=PORTAL30" target="_blank" style="color: #050505;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;">
                            http://www.motoronline.co.za/portal/page?_pageid=0,4049541,0_8493546&_dad=portal30&_schema=PORTAL30
                            </a>.
                        </p>
                    </p>
                </div>

                <div style="width:90%;margin-top:300pt;">
                     <p style="text-indent: 0pt;text-align: left;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 8pt;">
                        Registered with the National Credit Regulator - Reg Number NCRCB4
                    </p>
                </div>
            </div>
		';
		$this->append($intro);
		/* $container = $this
		->newTable(
				array(30, 5, 30, 5, 30),
				'margin:0;font-size:10px;vertical-align:top;',
				'',
				'padding:10px 0 0 0;'
		)
		->setCellValue(0, 0, $intro);

		$this->append($container->publish()); */


		/* --------------------------------- INFORMATION SUPPLIED /  INFORMATION VERIFIED --------------------------------- */


//		$vehicleInfo ='
//
//		';
//		$this->append($vehicleInfo);


		/* --------------------------------- ACCIDENT HISTORY --------------------------------- */

        $accidentHistory = '<br />
					<div style="margin-top:50pt;"></div>
            <div style="height: 30px;background-image:linear-gradient(to right,#9bb5c4,white 80%);"></div>
            <p style="margin-left: 20pt;text-align: left;margin-top: -45px; color: #030505;font-family: Arial, sans-serif;font-style: normal;font-weight: bold;text-decoration: none;font-size: 18pt;">
                Car Accident History Report
            </p>
            <ol>
                <li style="margin-left: 20px;color: #04a6cd;font-family: Arial, sans-serif;font-style: normal;font-weight: bold;text-decoration: none;font-size: 12pt;">
                    <span style="-webkit-border-radius: 0px 99px 99px 20px;-moz-border-radius: 0px 99px 99px 20px;border-radius: 0px 99px 99px 20px;max-width: 500px !important;padding-right: 10%;">
                        VEHICLE DETAILS SUPPLIED
                    </span>
                    <table style="width:90%;text-align: left;margin-left: -30px;margin-top: 10px;" >
                        <tr>
                            <td style="width:30%;">
                                <span style="line-height: 20pt;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    VIN Number:
                                </span>
                            </td>
                            <td style="width:70%;">
                                <span style="line-height: 20pt;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    ' . $this->getStockParam('vinNumber', '') . '
                                </span>
                            </td>
                        </tr>
                        <tr >
                            <td style="width:30%;">
                                <span style="line-height: 20pt;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    Engine Number:
                                </span>
                            </td>
                            <td style="width:70%;">
                                <span style="line-height: 20pt;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    ' . $this->getStockParam('engineNumber', '') . '
                                </span>
                            </td>
                        </tr>
                        <tr >
                            <td style="width:30%;">
                                <span style="line-height: 20pt;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    Registration Number:
                                </span>
                            </td>
                            <td style="width:70%;">
                                <span style="line-height: 20pt;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                   ' . $this->getStockParam('registrationNumber', '') . '
                                </span>
                            </td>
                        </tr>
                    </table>
                </li>
                <li style="margin-left: 20px;padding-top: 20px;color: #04a6cd;font-family: Arial, sans-serif;font-style: normal;font-weight: bold;text-decoration: none;font-size: 12pt;">
                    <span style="-webkit-border-radius: 0px 99px 99px 20px;-moz-border-radius: 0px 99px 99px 20px;border-radius: 0px 99px 99px 20px;max-width: 500px !important;padding-right: 10%;">
                       ACCIDENT HISTORY
                    </span>';



//        \Utility\Debug::errorLog('$ah_data',$ah_data);


        if (!empty($ah_data))
        {
            $accidentHistory .= '
                    <table style="width:100%;text-align: left;margin-left: -30px;margin-top: 10px;" >
                        <tr>
                            <td style="width:15%;">
                                <span style="margin-top:-17px;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    <p>Source</p>
                                </span>
                            </td>
                            <td style="width:15%;">
                                <span style="text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    <p>Assessment Date</p>
                                </span>
                            </td>
                            <td style="width:20%;">
                                <span style="text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    <p>Vehicle Description</p>
                                    </span>
                            </td>
                            <td style="width:15%;">
                                <span style="margin-top:-17px;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    <p>Vin Match</p>
                                </span>
                            </td>
                            <td style="width:15%;">
                                <span style="margin-top:-17px;text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    <p>REG Match</p>
                                </span>
                            </td>
                            <td style="width:20%;">
                                <span style="text-align: left;font-weight: bold;color: #030505;font-family: Arial, sans-serif;font-style: normal;text-decoration: none;font-size: 12pt;">
                                    <p>Repair Cost Indicator</p>
                                </span>
                            </td>
                        </tr>';



            foreach ($ah_data as $ah)
            {
                \Utility\Debug::errorLog('$ah',$ah);

                $accidentHistory .= '
					<tr>
                            <td style="width:15%;">
                                <p style="line-height: 13pt;text-align: left;color: #030505;font-family: Arial, sans-serif;font-size: 12pt;font-weight: normal;">
                                    ' . $ah['source'] . '
                                </p>
                            </td>
                            <td style="width:15%;">
                                <p style="line-height: 13pt;text-align: left;color: #030505;font-family: Arial, sans-serif;font-size: 12pt;font-weight: normal;">
                                    ' . str_replace('T',' ',$ah['assessmentDate']) . '
                                </p>
                            </td>
                            <td style="width:20%;">
                                <p style="line-height: 13pt;text-align: left;color: #030505;font-family: Arial, sans-serif;font-size: 12pt;font-weight: normal;">
                                    ' . $ah['vehicleDescription'] . '
                                </p>
                            </td>
                            <td style="width:15%;">
                                <p style="line-height: 13pt;text-align: left;color: #030505;font-family: Arial, sans-serif;font-size: 12pt;font-weight: normal;">
                                    ' . $ah['vinMatch'] . '
                                </p>
                            </td>
                            <td style="width:15%;">
                                <p style="line-height: 13pt;text-align: left;color: #030505;font-family: Arial, sans-serif;font-size: 12pt;font-weight: normal;">
                                    ' . $ah['regMatch'] . '
                                </p>
                            </td>
                            <td style="width:20%;">
                                <p style="line-height: 13pt;text-align: left;color: #030505;font-family: Arial, sans-serif;font-size: 12pt;font-weight: normal;">
                                    ' . $ah['estimatedRepairCost'] . '
                                </p>
                            </td>
                        </tr>
			';
            }
        }
        else
        {
            $accidentHistory .= '<table style="width:90%;text-align: left;margin-left: -30px;margin-top: 10px;" >
                            <tr>
                                <td style="width:90%;">
                                     <p style="text-indent: 0pt;text-align: left;color: #8A8379;font-family: Arial, sans-serif;font-style: normal;font-weight: normal;text-decoration: none;font-size: 12pt;">
                                        ' . $msg . '
                                    </p>
                                </td>
                            </tr>';
        }

		$accidentHistory .= '
			        </table>
                </li>
            </ol>';

		$this->append($accidentHistory);
		//$this->_page++;






		return;
	}


}