<?php
namespace Stock;


/**
 * A workflow.
 * @author andre.fourie
 */

class Workflow extends \Workspace\Workflow
{

	/**
	 * @var string
	 */
	protected $namespace = __NAMESPACE__;
	/**
	 * @var string
	 */
	protected $parentFeature = 'Stock';
	/**
	 * @var string
	 */
	protected $initState = 'This.NewItem';
	/**
	 * @var string
	 */
	protected $initTrigger = 'Stock.Create';
	/**
	 * @var string
	 */
	protected $primaryEntity = 'Stock';
	/**
	 * @var array
	 */
	protected $entityMap = array(
		'Stock'     => '\Stock\Entity\Stock',
		'Accessory' => '\Stock\Entity\Accessory'
	);
	/**
	 * @var array
	 */
	protected $linkMap = array(
		'Valuation'  => 'Stock',
		'PriceGuide' => 'Stock',
		'Auction'    => 'Stock',
		'Retail'     => 'Stock'
	);
	/**
	 * @var array
	 */
	protected $listen = array();
	/**
	 * @var array
	 */
	protected $reclaim = array();
	/**
	 * @var array
	 */
	protected $stateLabel = array(
		'PriceGuide'  => 'Price Guide',
		'TradeCenter' => 'Trade Center'
	);
	/**
	 * @var array
	 */
	protected $stateMap = array(
		'Global'       => array(
			'Actions' => array(
				'Tuhpi.Grid'                    => array(),
				'Tuhpi.Create'                  => array(),
				'Tuhpi.Print'                   => array(),
                'Tuhpi.PrintAccident'           => array(),
				'Tuhpi.List'                    => array(),
				'Import.Upload'                 => array(),
                'BulkImport.Upload'             => array(),
				'Stock.Grid'                    => array(),
				'Type.GetMmCode'                => array(),
				'Type.SelectList'               => array(),
				'Stock.Create'                  => array(),
				'Stock.CreateAuction'           => array(),
				'Stock.TradeCenterGrid'         => array(),
				'Report.StockControl'           => array(),
				'Make.SelectList'               => array(),
				'MakeMobi.SelectList'           => array(),
				'RegionMobi.SelectList'         => array(),
				'Year.SelectList'               => array(),
				'Accessory.List'                => array(),
				'Accessory.SelectList'          => array(),
				'Damage.List'                   => array(),
				'Damage.SelectList'             => array(),
				'Category.SelectList'           => array(),
				'Condition.SelectList'          => array(),
				'ExteriorColour.SelectList'     => array(),
				'InteriorColour.SelectList'     => array(),
				'Upholstery.SelectList'         => array(),
				'Paper.SelectList'              => array(),
				'Natis.SelectList'              => array(),
				'FullServiceHistory.SelectList' => array(),
				'TransmissionType.SelectList'   => array(),
				'FuelType.SelectList'           => array(),
				'Accessory.Create'              => array(),
				'Accessory.Update'              => array(),
				'Damage.Create'                 => array(),
				'Damage.Update'                 => array(),
				'ExteriorColour.Create'         => array(),
				'ExteriorColour.Update'         => array(),
				'InteriorColour.Create'         => array(),
				'InteriorColour.Update'         => array(),
				'FuelType.Create'               => array(),
				'FuelType.Update'               => array(),
				'TransmissionType.Create'       => array(),
				'TransmissionType.Update'       => array(),
				'FullServiceHistory.Create'     => array(),
				'FullServiceHistory.Update'     => array(),
				'Natis.Create'                  => array(),
				'Natis.Update'                  => array(),
				'Paper.Create'                  => array(),
				'Paper.Update'                  => array(),
				'Upholstery.Create'             => array(),
				'Upholstery.Update'             => array(),
				'Utility.ListMakes'             => array(),
				'Utility.ListModels'            => array(),
				'Utility.ListTypes'             => array(),
				'Utility.TransUnionFromMmCode'  => array(),
				'Utility.TransUnionForHPI'      => array(),
                'Utility.TransUnionForHPIAccident'      => array(),
				'PricingHistory.Grid'           => array()
			)
		),
		'NewItem'      => array(
			'InitRoute' => 'Stock.routeNewItem'
		),
		/*
		 * Internal states.
		 */
		'Stock'        => array(
			'Actions' => array(
				'Stock.Update' => array(),
				'Stock.View'   => array(),
				'Pdf.Print'    => array(),
				'Tuhpi.Print'  => array(),
                'Tuhpi.PrintAccident'  => array()
			),
			'Routes'  => array(
				'Stock.SendToRetail'      => array(),
				'Stock.SendToPriceGuide'  => array(
					'Destination'      => 'PriceGuide.NewItem',
					'ContractRequired' => true
				),
				'Stock.SendToRetail'      => array(
					'Destination'      => 'Retail.NewItem',
					'ContractRequired' => true
				),
				'Stock.SendToAuction'     => array(
					'Destination'      => 'Auction.NewItem',
					'ContractRequired' => true
				),
				'Stock.SendToTradeCenter' => array(),
				'Stock.MoveToArchive'  => array(
					'Destination' => 'This.Archived'
				)
			)
		),
		'Sold'         => array(
			'Actions'   => array(
				'Stock.LimitedUpdate' => array(),
				'Stock.View'          => array(),
				'Pdf.Print'           => array()
			),
			'RouteBack' => array(
				'Action' => 'Stock.routeAuctionHandover'
			),
			'Routes'    => array()
		),
		'Retail'       => array(
			'Actions' => array(
				'Stock.LimitedUpdate' => array(),
				'Stock.View'          => array(),
				'Pdf.Print'           => array()
			),
			'Routes'  => array(
				'Stock.ReclaimFromRetail' => array()
			)
		),
		'Trade Center' => array(
			'Actions' => array(
				'Stock.Update'        => array(),
				'Stock.LimitedUpdate' => array(),
				'Stock.View'          => array(),
				'Pdf.Print'           => array()
			),
			'Routes'  => array(
				'Stock.SendToAuction' => array(
					'Destination'      => 'Auction.NewItem',
					'ContractRequired' => true
				),
				'Stock.SendToDealer'  => array(
					'Destination' => 'This.Stock'
				)
			)
		),
		'Archived'     => array(
			'Actions' => array(
				'Stock.LimitedUpdate' => array(),
				'Stock.View'          => array(),
				'Pdf.Print'           => array()
			),
			'Routes'  => array(
				'Stock.MoveToStock' => array(
					'Destination' => 'This.Stock'
				)
			)
		),
		/*
		 * External states.
		 */
		'Valuation'    => array(
			'Actions'   => array(
				'Stock.Update' => array(),
				'Stock.View'   => array(),
				'Pdf.Print'    => array(),
				'Tuhpi.Print'  => array(),
                'Tuhpi.PrintAccident'  => array()
			),
			'RouteBack' => array(
				'State' => 'This.Stock'
			)
		),
		'Price Guide'  => array(
			'Actions'   => array(
				'Stock.LimitedUpdate' => array(),
				'Stock.View'          => array(),
				'Pdf.Print'           => array(),
				'Tuhpi.Print'         => array(),
                'Tuhpi.PrintAccident'  => array()
			),
			'RouteBack' => array(
				'State' => 'This.Stock'
			)
		),
		'Auction'      => array(
			'Actions'   => array(
				'Stock.Update'        => array(),
				'Stock.LimitedUpdate' => array(),
				'Stock.View'          => array(),
				'Pdf.Print'           => array(),
				'Tuhpi.Print'         => array(),
                'Tuhpi.PrintAccident'  => array()
			),
			'RouteBack' => array(
				'Action' => 'Stock.routeAuctionHandover'
			)
		),
        'Relist'     => array(
            'Actions'   => array(
                'Stock.Update'        => array(),
                'Stock.LimitedUpdate' => array(),
                'Stock.View'          => array(),
                'Pdf.Print'           => array(),
                'Tuhpi.Print'         => array(),
                'Tuhpi.PrintAccident'  => array()
            ),
            'RouteBack' => array(
                'Action' => 'Stock.routeAuctionHandover'
            )
        ),
	);


}
